#!/usr/bin/env perl

use strict;
use warnings;
use charnames ':full';
use Fcntl;
use IO::File;

my $cmdname = $0; $cmdname =~ s{.*/}{};
my $usage = "Usage: $cmdname dehypht.tex depht.rules";
die $usage unless @ARGV == 2;
my $infile = $ARGV[0];
my $outfile = $ARGV[1];

my $in = new IO::File $infile, O_RDONLY or die "$cmdname: $infile: $!\n";
my $in_patterns = 0;
my @patterns;
while (<$in>) {
   chomp;
   if (m{^\\patterns\{}) {
      $in_patterns = 1; next;
   }
   next unless $in_patterns;
   last if m{^\}};
   my @entries = split /\s+/, $_;
   foreach my $entry (@entries) {
      next if $entry =~ m{\\c\{.*?\}}; # duplicates
      if ($entry =~ m{^\\n\{(.*?)\}}) {
	 $entry = $1;
      }
      $entry =~ s{"a}{\N{LATIN SMALL LETTER A WITH DIAERESIS}}g;
      $entry =~ s{"o}{\N{LATIN SMALL LETTER O WITH DIAERESIS}}g;
      $entry =~ s{"u}{\N{LATIN SMALL LETTER U WITH DIAERESIS}}g;
      $entry =~ s{\\[39]}{\N{LATIN SMALL LETTER SHARP S}}g;
      push(@patterns, $entry);
   }
}
$in->close;
die "$cmdname: no patterns found\n" unless @patterns > 0;
my $out = new IO::File $outfile, O_WRONLY|O_CREAT|O_TRUNC, 0666
   or die "$cmdname: $outfile: $!\n";
binmode($out, ":utf8");
print $out join("\n", @patterns), "\n";
$out->close;
